============
bisos.facter
============

.. contents::
   :depth: 3
..

Overview
========

bisos.facter: Adoption and adaptation of facter to Python and
PyCS-Framework and BISOS for use with BISOS-CMDB.

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in
http://www.by-star.net/PLPC/180047

Installation
============

::

   sudo pip install bisos.facter

Usage
=====

::

   bin/facter.cs
